﻿using Autodesk.AutoCAD.DatabaseServices;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using Extensions;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.EditorInput;
using System.ComponentModel.DataAnnotations;

namespace RoadReport.Objects
{
    public class Data
    {
        #region ----------------------------------------- Properties
        
        internal ObjectId ObjectID { get; set; }
        public string Handle { get {return ObjectID.Handle.ToString(); } }
        public Double Area { get; set; }
        public Double Length { get; set; }
        public string Layer{get;set;}
        #endregion -------------------------------------- Properties

	
        #region ----------------------------------------- Constructors
	    public Data()
        { }

        public Data(Transaction _tr, ObjectId _oid)
        {
            Area = double.PositiveInfinity;
            Length = double.PositiveInfinity;
            ObjectID = _oid;
            using(Entity _ent = (Entity)_tr.GetObject(_oid, OpenMode.ForRead, false,true))
            {
                Layer = _ent.Layer;
                if (typeof(Hatch).IsAssignableFrom(_ent.GetType()))
                {
                    Area = Math.Round(((Hatch)_ent).Area, 3);
                }
                else if (typeof(Curve).IsAssignableFrom(_ent.GetType()))
                {
                    Curve _curve = (Curve)_ent;
                    Area = Math.Round(_curve.Area, 3);
                    Length = Math.Round(_curve.GetDistanceAtParameter(_curve.EndParam) - _curve.GetDistanceAtParameter(_curve.StartParam), 3);
                }
            }
        }
        #endregion -------------------------------------- Constructors


        #region ----------------------------------------- private Methods        

        #endregion -------------------------------------- private Method


        #region ----------------------------------------- Methods
        public void ZoomTo()
        {
            Document doc = Application.DocumentManager.MdiActiveDocument;
            Database db = doc.Database;
            Editor ed = doc.Editor;
            
            if (db.Equals(ObjectID.Database))
            {
                Extents3d ext;

                using (Transaction tr = db.TransactionManager.StartTransaction())
                {
                    Entity ent = (Entity)tr.GetObject(ObjectID, OpenMode.ForRead);
                    ext = ent.GeometricExtents;
                }

                ext.TransformBy(ed.CurrentUserCoordinateSystem.Inverse());

                ed.ZoomWin(ext.MinPoint, ext.MaxPoint);
            }
        }
        #endregion -------------------------------------- Method


    }
}
